
IP adresses in internal HTTP headers.
-------

**Description:**

Whenever IP adresses are used in HTTP headers in internal structures of your organization, 
an attacker could use these to enlarge his attack vector and recon your 
internal infrastructures.


**Solution:**

Never use IP adresses in internal HTTP headers.

	